@@ -74,7 +74,7 @@ dbaSP <- function(SPx, Avg, sm = summary(SPx),
 
     ## use matrices for easy allocation/subsetting; one matrix per data type
     DFchar <- matrix(as.character(NA), nrow = rowz, ncol = 4, dimnames = list(seq(rowz), c("station_id", "gtype", "ddate", "bdate")))
-    DFnum_colnames <- c("height", "AvgLayerIndex", "thickness", "hardness", "gsize", "density", "tsa", "rta",
+    DFnum_colnames <- c("height", "AvgLayerIndex", "thickness", "hardness", "gsize", "density", "temperature", "tsa", "rta",
                         "queryLayerIndex", "queryLayerHeight", "queryLayerDepth", "sim", "layerOfInterest", "p_unstable", "slab_rhogs")
     DFnum <- matrix(as.double(NA), nrow = rowz, ncol = length(DFnum_colnames),
                     dimnames = list(seq(rowz), DFnum_colnames))
@@ -102,6 +102,7 @@ dbaSP <- function(SPx, Avg, sm = summary(SPx),
     if ("bdate" %in% names(warpedLayers)) DFchar[k_insert_to, "bdate"] <- as.character(warpedLayers$bdate[k_insert_from])
     if ("gsize" %in% names(warpedLayers)) DFnum[k_insert_to, "gsize"] <- warpedLayers$gsize[k_insert_from]
     if ("density" %in% names(warpedLayers)) DFnum[k_insert_to, "density"] <- warpedLayers$density[k_insert_from]
+    if ("temperature" %in% names(warpedLayers)) DFnum[k_insert_to, "temperature"] <- warpedLayers$temperature[k_insert_from]
     if ("tsa" %in% names(warpedLayers)) DFnum[k_insert_to, "tsa"] <- warpedLayers$tsa[k_insert_from]
     if ("rta" %in% names(warpedLayers)) DFnum[k_insert_to, "rta"] <- warpedLayers$rta[k_insert_from]
     if ("p_unstable" %in% names(warpedLayers)) DFnum[k_insert_to, "p_unstable"] <- warpedLayers$p_unstable[k_insert_from]
@@ -152,6 +153,7 @@ dbaSP <- function(SPx, Avg, sm = summary(SPx),
       as.character(median(as.POSIXct(DFsubset$bdate, tz = tz), na.rm = TRUE)),               # bdate
       as.character(round(median(as.double(DFsubset$gsize), na.rm = TRUE), digits = 2)),      # gsize
       as.character(round(median(as.double(DFsubset$density), na.rm = TRUE), digits = 2)),    # density
+      as.character(round(median(as.double(DFsubset$temperature), na.rm = TRUE), digits = 2)),# temperature
       as.character(round(median(as.double(DFsubset$tsa), na.rm = TRUE), digits = 2)),        # tsa
       as.character(round(median(as.double(DFsubset$rta), na.rm = TRUE), digits = 2)),        # rta
       as.character(round(median(as.double(DFsubset$p_unstable), na.rm = TRUE), digits = 2)), # p_unstable
@@ -184,7 +186,7 @@ dbaSP <- function(SPx, Avg, sm = summary(SPx),
     ## get the grain type frequencies for each layer &
     ## compute median over layer properties that correspond to the most prevalent grain type
     cnames <- c("medianPredominantHeight", "medianPredominantDepth", "gtype", "distribution", "hardness",
-                "ddate", "bdate", "gsize", "density", "tsa", "rta", "p_unstable", "slab_rhogs", "ppu", "ppu_all")
+                "ddate", "bdate", "gsize", "density", "temperature", "tsa", "rta", "p_unstable", "slab_rhogs", "ppu", "ppu_all")
     avgLyrs <- lapply(DFgrid, averageOverLayers, DF = DF)
     avgLyrs <- as.data.frame(do.call("rbind", avgLyrs))
     colnames(avgLyrs) <- cnames
@@ -210,7 +212,7 @@ dbaSP <- function(SPx, Avg, sm = summary(SPx),
     if (length(drop) > 0) {
       Avg <- suppressWarnings(snowprofile(type = "aggregate", layers = snowprofileLayers(height = DFgrid[-drop], gtype = avgLyrs$gtype[-drop], hardness = as.double(avgLyrs$hardness[-drop]),
                                                                         ddate = as.POSIXct(avgLyrs$ddate[-drop], tz = tz), bdate = as.POSIXct(avgLyrs$bdate[-drop], tz = tz),
-                                                                        gsize = as.double(avgLyrs$gsize[-drop]), density = as.double(avgLyrs$density[-drop]),
+                                                                        gsize = as.double(avgLyrs$gsize[-drop]), density = as.double(avgLyrs$density[-drop]), temperature = as.double(avgLyrs$temperature[-drop]),
                                                                         tsa = as.double(avgLyrs$tsa[-drop]), rta = as.double(avgLyrs$rta[-drop]),
                                                                         p_unstable = as.double(avgLyrs$p_unstable[-drop]), slab_rhogs = as.double(avgLyrs$slab_rhogs[-drop]),
                                                                         ppu = as.double(avgLyrs$ppu[-drop]), ppu_all = as.double(avgLyrs$ppu_all[-drop]),
@@ -220,7 +222,7 @@ dbaSP <- function(SPx, Avg, sm = summary(SPx),
     } else {
       Avg <- suppressWarnings(snowprofile(type = "aggregate", layers = snowprofileLayers(height = DFgrid, gtype = avgLyrs$gtype, hardness = as.double(avgLyrs$hardness),
                                                                                          ddate = as.POSIXct(avgLyrs$ddate, tz = tz), bdate = as.POSIXct(avgLyrs$bdate, tz = tz),
-                                                                                         gsize = as.double(avgLyrs$gsize), density = as.double(avgLyrs$density),
+                                                                                         gsize = as.double(avgLyrs$gsize), density = as.double(avgLyrs$density), temperature = as.double(avgLyrs$temperature),
                                                                                          tsa = as.double(avgLyrs$tsa), rta = as.double(avgLyrs$rta),
                                                                                          p_unstable = as.double(avgLyrs$p_unstable), slab_rhogs = as.double(avgLyrs$slab_rhogs),
                                                                                          ppu = as.double(avgLyrs$ppu), ppu_all = as.double(avgLyrs$ppu_all),
